@@ -15,6 +15,7 @@ class API(object):
     _client_id = None
     _client_secret = None
     _identity_token = None
+    _auth_scope = None
 
     try:
         _client_id = getattr(
@@ -23,6 +24,8 @@ class API(object):
             settings, 'CLIENT_SECRET', _client_secret)
         _auth_token_url = getattr(
             settings, 'OAUTH2_TOKEN_URL', _auth_token_url)
+        _auth_scope = getattr(
+            settings, 'OAUTH2_SCOPE', _auth_scope)
     except Exception as e:
         pass
 
@@ -54,6 +57,7 @@ class API(object):
     def refresh_identity_token(self):
         _payload = {
             'grant_type': 'client_credentials',
+            'scope': self._auth_scope,
             'client_id': self._client_id,
             'client_secret': self._client_secret
         }
