@@ -64,8 +64,8 @@ class Accounts(Resource):
         # Set the Operation being executed
         # Set the Original request sent before serialization
         super().set_operation(operation).set_request(payload)
-        data={}
-        
+        data = {}
+
         if operation in [super().PDF_TO_JSON]:
             data.update({
                 "bank_id": super().get_bank_id(),
@@ -196,9 +196,9 @@ class Accounts(Resource):
         elif operation == super().PDF_TO_JSON or operation == super().GET_JSON_PDF:
             # data = payload
             data.update(payload)
-            if payload.get("callback_url", None) is None or payload.get("callback_url", '') == '': 
-                data['bank_sync_call_back']=payload.get("callback_url", None)
-        
+            if payload.get("callback_url", None) is None or payload.get("callback_url", '') == '':
+                data['bank_sync_call_back'] = payload.get("callback_url", None)
+
         elif operation == super().FOREX_RATE:
             if super().get_bank_id() == super().EQUITY:
                 data.update({
@@ -206,7 +206,7 @@ class Accounts(Resource):
                     "countryCode": payload.get("country_code", ""),
                     "currencyCode": payload.get("currency_code", ""),
                     "toCurrency": payload.get("to_currency", ""),
-                    "amount": round(float(payload.get("amount",0)),2),
+                    "amount": round(float(payload.get("amount", 0)), 2),
                 })
 
         data.update(payload.get("additional_properties", {}))
@@ -373,7 +373,7 @@ class Accounts(Resource):
 
                 try:
                     if isinstance(response_data, str):
-                        response_data = '{}{}'.format(response_data,'"}]}}')
+                        response_data = '{}{}'.format(response_data, '"}]}}')
                         response_data = json.loads(response_data)
                 except Exception as e:
                     data['error'] = e
@@ -437,35 +437,84 @@ class Accounts(Resource):
                     data["transactions"].append(transaction)
 
         elif super().get_operation() == super().PDF_TO_JSON or super().get_operation() == super().GET_JSON_PDF:
-            data=self.standardize_pdf_to_json(response_data=response_data)
+            data = self.standardize_pdf_to_json(response_data=response_data)
 
         elif super().get_operation() == super().FOREX_RATE:
 
-                if isinstance(response_data, dict):
-                    data["message"] = response_data.get("message", "")
-                    data["code"] = f'{response_data.get("code", -111111)}'
+            if isinstance(response_data, dict):
+                data["message"] = response_data.get("message", "")
+                data["code"] = f'{response_data.get("code", -111111)}'
 
-                    if 'data' in response_data.keys():
-                        data['data']={
-                            "converted_amount": response_data.get('data',{}).get("convertedAmount", -1),
-                            "rate": response_data.get('data',{}).get("rate", -1),
-                            "from_amount": response_data.get('data',{}).get("fromAmount", -1),
-                            "rate_code": response_data.get('data',{}).get("rateCode", "")
-                        }
+                if 'data' in response_data.keys():
+                    data['data'] = {
+                        "converted_amount": response_data.get('data', {}).get("convertedAmount", -1),
+                        "rate": response_data.get('data', {}).get("rate", -1),
+                        "from_amount": response_data.get('data', {}).get("fromAmount", -1),
+                        "rate_code": response_data.get('data', {}).get("rateCode", "")
+                    }
 
-                else:
-                    data['response'] = response_data
+            else:
+                data['response'] = response_data
+
+        elif super().get_operation() == super().JOBS_ACCOUNT_BALANCES:
+            data = []
+            if super().get_bank_id() == super().COOP:
+                for account_balance_data in response_data.get('data', []):
+                    data.append({
+                        "status": account_balance_data.get("status", -1),
+                        "created_at": account_balance_data.get("created_at", ''),
+                        "available_balance": account_balance_data.get('account_balance_response', {}).get("AvailableBalance", ''),
+                    })
+
+                    if account_balance_data.get("status", -1) != 0:
+                        data["available_balance_error"] = account_balance_data.get(
+                            'account_balance_response', {})
+
+        elif super().get_operation() == super().JOBS_ACCOUNT_STATEMENT:
+            data = []
+            if super().get_bank_id() == super().COOP:
+
+                for account_statement_data in response_data.get('data', []):
+                    data.append({
+                        "status": account_statement_data.get("status", -1),
+                        "created_at": account_statement_data.get("created_at", ''),
+                        "transactions": [],
+                    })
+
+                    if account_statement_data.get("status", -1) != 0:
+                        data[-1]["transaction_error"] = account_statement_data.get(
+                            'account_statement_response', {})
+
+                    else:
+                        transactions_data = account_statement_data.get(
+                            'account_statement_response', {}).get("Transactions", [])
+                        for transaction in transactions_data:
+                            transaction_data = {
+                                "date": transaction.get("TransactionDate", ''),
+                                "description": transaction.get("Narration", ''),
+                                "reference": transaction.get("TransactionReference", ''),
+                            }
+
+                            if transaction.get("TransactionType", "") == "D":
+                                transaction_data["amount"] = transaction.get(
+                                    "DebitAmount", "")
+                                transaction_data["type"] = "Debit"
+
+                            elif transaction.get("TransactionType", "") == "C":
+                                transaction_data["amount"] = transaction.get(
+                                    "CreditAmount", "")
+                                transaction_data["type"] = "Credit"
+
+                            data[-1].get("transactions", []
+                                         ).append(transaction_data)
 
         if bool(data):
-            
-            if 'transactions' in data.keys() and 'code' in data.keys():
-                if len(data["transactions"])==0 and int(data["code"])==-111111:
-                    data['error'] = response_data
-
+            if isinstance(data, dict):
+                if 'transactions' in data.keys() and 'code' in data.keys():
+                    if len(data["transactions"]) == 0 and int(data["code"]) == -111111:
+                        data['error'] = response_data
             return data
         if super().get_bank_id() in super().THIRD_PARTY_BANKING.keys():
             return response_data
 
         return response_data
-
-
