@@ -66,6 +66,26 @@ class Bank(Resource):
     def bank_types(self):
         return self.bank_types_by_id()
 
+    # This is a 'global' function
+    # Used to get results of jobs that were scheduled
+    def jobs(self, operation=None, payload=None):
+
+        # The response returned is the raw response sent by banks before any standardizations
+        rsp = self.exec_global_function(
+            operation=operation, payload=payload).response()
+
+        # The jobs that are currently being run are Account APIs get Account Balance and Account Full Statement API
+        # For the above reason we will then initia.ize an Account Class that is responsible for standardizing Account APIs responses
+        accounts = Accounts()
+        # Set the bank id to identify the bank response being standardized
+        accounts.set_bank_id(bank_id=rsp.get('bank_id'))
+        # Set the operation to identify the bank api being standardized
+        accounts.set_operation(operation=operation)
+        # The set the response method is where the responses are standardized
+        accounts.set_response(response=rsp)
+
+        return accounts
+
     # This is a 'global' function used to:
     # 1. Register a user's I.P.N.'s in Nash
     # 2. Get a user's registered I.P.N.'s in Nash
@@ -79,44 +99,47 @@ class Bank(Resource):
     # the response
     def ipn(self, operation=None, payload=None):
         # Get the user passed url
-        user_url=payload.get('url', '')
+        user_url = payload.get('url', '')
 
         # if a user passed a url, swap it with the service url
         if 'url' in payload.keys():
-            payload['url']=self.bank_sync_ipn_urls.get("payments", "")
+            payload['url'] = self.bank_sync_ipn_urls.get("payments", "")
 
         # excute the IPN call
         exec_global = self.exec_global_function(
             operation=operation, payload=payload)
-        
+
         try:
-            
+
             if operation in [super().IPN_REGISTER]:
                 # get the response and change the url saved, which it the service url, with the user url
-                rsp=super().response()
-                rsp['url']=user_url
+                rsp = super().response()
+                rsp['url'] = user_url
                 super().set_response(response=rsp)
 
             # If the operation performed is to create an IPN
             if operation == super().IPN_REGISTER:
                 # If succesfull Nash returns the generated client id and client secret
-                if 'client_id' in super().response().keys():
+                if 'client_id' in super().response().keys() and 'client_secret' in super().response().keys():
+                    signature = self.generate_signature(secret=super().response().get(
+                        'client_secret'), message=f"{super().response().get('client_id')}:{super().response().get('client_secret')}")
 
-                    IPN.objects.create(bank_id=payload.get('bank_id', ''), client_id=super().response().get('client_id', ''), client_secret=super().response().get(
-                        'client_secret', ''), account_number=payload.get('account_number', ''), url=user_url)
+                    IPN.objects.create(bank_id=payload.get('bank_id', ''), client_id=super().response().get(
+                        'client_id', ''), signature=signature, country_code=payload.get('country_code', ''), account_number=payload.get('account_number', ''), url=user_url)
 
             # If the operation performed is to update an IPN
             elif operation == super().IPN_GET:
                 # If succesfull Nash returns the client id and account_number
-                if 'client_id' in super().response().keys() and 'account_number' in super().response().keys() :
+                if 'client_id' in super().response().keys() and 'account_number' in super().response().keys():
 
-                    data = IPN.objects.get(client_id=super().response().get('client_id', ''),account_number=super().response().get('account_number', ''))
+                    data = IPN.objects.get(client_id=super().response().get(
+                        'client_id', ''), account_number=super().response().get('account_number', ''))
 
                     # if bool(len(data)):
                     #     data = data.first()
 
-                    rsp=super().response()
-                    rsp['url']=data.url
+                    rsp = super().response()
+                    rsp['url'] = data.url
                     super().set_response(response=rsp)
 
             # If the operation performed is to update an IPN
@@ -124,12 +147,12 @@ class Bank(Resource):
                 # If succesfull Nash returns the client id
                 if 'client_id' in super().response().keys():
 
-                    data = IPN.objects.get(client_id=payload.get('client_id', ''),account_number=payload.get('account_number', ''))
+                    data = IPN.objects.get(client_id=payload.get(
+                        'client_id', ''), account_number=payload.get('account_number', ''))
 
-                    # if bool(len(data)):
-                    #     data = data.first()
                     if 'client_secret' in super().response().keys():
-                        data.client_secret = super().response().get('client_secret', '')
+                        data.signature = self.generate_signature(secret=super().response().get(
+                            'client_secret'), message=f"{super().response().get('client_id')}:{super().response().get('client_secret')}")
 
                     data.save()
 
@@ -138,15 +161,16 @@ class Bank(Resource):
                 # If succesfull Nash returns the client id
                 if 'client_id' in super().response().keys():
 
-                    data = IPN.objects.get(client_id=payload.get('client_id', ''))
-
-                    # if bool(len(data)):
-                    #     data = data.first()
+                    data = IPN.objects.get(
+                        client_id=payload.get('client_id', ''))
+                        
                     if 'bank_id' in payload.keys():
                         data.bank_id = payload.get('bank_id')
                     if 'account_number' in payload.keys():
                         data.account_number = payload.get(
                             'account_number')
+                    if 'country_code' in payload.keys():
+                        data.country_code = payload.get('country_code')
                     if 'url' in payload.keys():
                         data.url = user_url
                     if 'status' in payload.keys():
@@ -163,13 +187,12 @@ class Bank(Resource):
 
                     data = IPN.objects.get(client_id=payload.get(
                         'client_id', ''))
-
-                    # if bool(len(data)):
+                        
                     data.delete()
 
         except ObjectDoesNotExist:
             print("Either the blog or entry doesn't exist.")
-            
+
         return exec_global
 
     # This is a 'global' function
