@@ -11,10 +11,11 @@ import base64
 import time
 import threading
 from bank_sync.models import IPN
-from bank_sync.models import IPN
 from django.core.exceptions import ObjectDoesNotExist
 
-
+# This class will be inherited by sub entities e.g. Accounts Class and Payments Class
+# It has common methods that these entities will override and implement
+# As wll as methods that can be used by any of the Entities
 class Resource(API, Operations):
 
     _bank_id = 0
@@ -118,6 +119,8 @@ class Resource(API, Operations):
     def get_callback_data(self):
         return self._callback_data
 
+    # The method used to execute the API calls to the Bank Integrations APIs
+    # It uses methods/variables from the Operations Class to combine and create the appropriate API URL endpoint and method to be executed based on the banking operation to be perfomed
     def read(self, payload=None, params=''):
         # Check if the bank exists
         if self.get_bank_id() in self.BANKS_CONF.keys() or self.get_bank_id() in self.THIRD_PARTY_BANKING.keys():
@@ -206,7 +209,7 @@ class Resource(API, Operations):
                     threading.Thread(target=self._send_to_callback,
                                      args=[response, callback_url]).start()
 
-    # This method is used to standardize callbacks sent
+    # This method is used to standardize callbacks received
     def standardize_callback(self, callback_data={}, forward=True):
 
         response = {
@@ -257,10 +260,10 @@ class Resource(API, Operations):
 
                     if 'Source' in callback_data.keys():
                         response["message"] = callback_data.get(
-                            "MessageDescription", "")
+                            "Source", {}).get("ResponseDescription", "")
                     elif 'source' in callback_data.keys():
                         response["message"] = callback_data.get(
-                            "source", {}).get("narration", "")
+                            "source", {}).get("responseDescription", "")
 
                     if 'Destinations' in callback_data.keys():
                         if isinstance(callback_data.get("Destinations", {}), dict):
@@ -340,7 +343,7 @@ class Resource(API, Operations):
 
         return response
 
-    # This method is used to standardize IPNs sent
+    # This method is used to standardize IPN responses received
     def standardize_ipn(self, ipn_data={}, forward=True):
 
         ipn = None
@@ -399,9 +402,10 @@ class Resource(API, Operations):
 
         except ObjectDoesNotExist:
             print("Either the blog or entry doesn't exist.")
-        
+
         return response
 
+    # This method is used to standardize pdf_to_json responses
     def standardize_pdf_to_json(self, response_data):
         std_data_list = []
         std_data = {}
@@ -793,26 +797,25 @@ class Resource(API, Operations):
                                          callback=callback,
                                          request=request, bank_id=self.get_bank_id(), type_code=self.get_operation())
 
+    # This method is used to save callback responses received
     def save_callback_data(self, saved_callback, callback_data):
-        # if len(saved_callback):
-        #     callback = saved_callback.first()
         callback = saved_callback
         callback.response = callback_data
         callback.response_time = timezone.now()
         callback.save()
 
+    # This method is used to save IPN responses received
     def save_ipn_data(self, saved_ipn, ipn_data):
-        # if len(saved_ipn):
-        #     saved_ipn = saved_ipn.first()
         saved_ipn = saved_ipn
         IPNData.objects.create(ipn=saved_ipn, response=ipn_data)
 
+    # This method is used to generate a signature
     def generate_signature(self, secret, message):
         digest = hmac.new(secret.encode(), msg=message.encode(
         ), digestmod=hashlib.sha256).digest()
         return base64.b64encode(digest).decode()
 
-    # Use this method to send data to a callback
+    # Use this method to send data to a saved callback URL
     def _send_to_callback(self, response, callback_url='', sleep=True, sleep_time=1):
         if sleep:
             time.sleep(1*sleep_time)
